@@ -1,3 +1,6 @@
+import logging
+import time
+
 import asyncio
 import tarfile
 import os
@@ -6,7 +9,6 @@ import shutil
 from pathlib import Path
 from aiofile import async_open
 from azure.storage.blob.aio import BlobServiceClient
-from azure.core.exceptions import ResourceNotFoundError, ResourceExistsError
 
 class Decompressor():
 
@@ -33,13 +35,23 @@ class Decompressor():
         self.cleanup(local_temp_dir)
 
     async def process_blob_file(self, container_name, blob_client, dest_dir, local_file):
-        print(f"start processing file: {local_file}")
-
+        download_start = time.time()
+        logging.info(f"start downloading file: {local_file}")
         await self.download_compressed_file(blob_client, local_file)
-        decompression_dir = self.decompress(local_file)
-        await self.upload_decompressed_files(container_name, dest_dir, decompression_dir)
+        download_end = time.time()
+        logging.info(f"end downloading file: {local_file}, takes {download_end - download_start}")
 
-        print(f"start processing file: {local_file}")
+        decompress_start = time.time()
+        logging.info(f"start decompressing file: {local_file}")
+        decompression_dir = self.decompress(local_file)
+        decompress_end = time.time()
+        logging.info(f"end decompressing file: {local_file}, takes {decompress_end - decompress_start}")
+        
+        upload_start = time.time()
+        logging.info(f"start uploading files for: {local_file}")
+        await self.upload_decompressed_files(container_name, dest_dir, decompression_dir)
+        upload_end = time.time()
+        logging.info(f"end uploading files for: {local_file}, takes {upload_end - upload_start}")
 
     async def download_compressed_file(self, blob_client, local_file):
         async with async_open(local_file, 'wb') as afp:
